package org.apache.bcel.generic;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.classfile.ConstantDouble;
import org.apache.bcel.classfile.ConstantFloat;
import org.apache.bcel.classfile.ConstantInteger;
import org.apache.bcel.classfile.ConstantLong;
import org.apache.bcel.classfile.ConstantUtf8;
import org.apache.bcel.classfile.ElementValue;
import org.apache.bcel.classfile.SimpleElementValue;
import org.apache.bcel.generic.ConstantPoolGen;
import org.apache.bcel.generic.ElementValueGen;

public class SimpleElementValueGen extends ElementValueGen {
  private final int idx;
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, boolean value) {
    super(type, cpGen);
    if (value) {
      this.idx = getConstantPool().addInteger(1);
    } else {
      this.idx = getConstantPool().addInteger(0);
    } 
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, byte value) {
    super(type, cpGen);
    this.idx = getConstantPool().addInteger(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, char value) {
    super(type, cpGen);
    this.idx = getConstantPool().addInteger(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, double value) {
    super(type, cpGen);
    this.idx = getConstantPool().addDouble(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, float value) {
    super(type, cpGen);
    this.idx = getConstantPool().addFloat(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, int value) {
    super(type, cpGen);
    this.idx = getConstantPool().addInteger(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, long value) {
    super(type, cpGen);
    this.idx = getConstantPool().addLong(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, short value) {
    super(type, cpGen);
    this.idx = getConstantPool().addInteger(value);
  }
  
  public SimpleElementValueGen(int type, ConstantPoolGen cpGen, String value) {
    super(type, cpGen);
    this.idx = getConstantPool().addUtf8(value);
  }
  
  protected SimpleElementValueGen(int type, int idx, ConstantPoolGen cpGen) {
    super(type, cpGen);
    this.idx = idx;
  }
  
  public SimpleElementValueGen(SimpleElementValue value, ConstantPoolGen cpool, boolean copyPoolEntries) {
    super(value.getElementValueType(), cpool);
    if (!copyPoolEntries) {
      this.idx = value.getIndex();
    } else {
      switch (value.getElementValueType()) {
        case 115:
          this.idx = cpool.addUtf8(value.getValueString());
          return;
        case 73:
          this.idx = cpool.addInteger(value.getValueInt());
          return;
        case 66:
          this.idx = cpool.addInteger(value.getValueByte());
          return;
        case 67:
          this.idx = cpool.addInteger(value.getValueChar());
          return;
        case 74:
          this.idx = cpool.addLong(value.getValueLong());
          return;
        case 70:
          this.idx = cpool.addFloat(value.getValueFloat());
          return;
        case 68:
          this.idx = cpool.addDouble(value.getValueDouble());
          return;
        case 90:
          if (value.getValueBoolean()) {
            this.idx = cpool.addInteger(1);
          } else {
            this.idx = cpool.addInteger(0);
          } 
          return;
        case 83:
          this.idx = cpool.addInteger(value.getValueShort());
          return;
      } 
      throw new IllegalArgumentException("SimpleElementValueGen class does not know how to copy this type " + getElementValueType());
    } 
  }
  
  public void dump(DataOutputStream dos) throws IOException {
    dos.writeByte(getElementValueType());
    switch (getElementValueType()) {
      case 66:
      case 67:
      case 68:
      case 70:
      case 73:
      case 74:
      case 83:
      case 90:
      case 115:
        dos.writeShort(this.idx);
        return;
    } 
    throw new IllegalStateException("SimpleElementValueGen doesnt know how to write out type " + getElementValueType());
  }
  
  public ElementValue getElementValue() {
    return new SimpleElementValue(getElementValueType(), this.idx, getConstantPool().getConstantPool());
  }
  
  public int getIndex() {
    return this.idx;
  }
  
  public int getValueInt() {
    if (getElementValueType() != 73)
      throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue"); 
    ConstantInteger c = (ConstantInteger)getConstantPool().getConstant(this.idx);
    return c.getBytes();
  }
  
  public String getValueString() {
    if (getElementValueType() != 115)
      throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue"); 
    ConstantUtf8 c = (ConstantUtf8)getConstantPool().getConstant(this.idx);
    return c.getBytes();
  }
  
  public String stringifyValue() {
    ConstantInteger c;
    ConstantLong j;
    ConstantDouble d;
    ConstantFloat f;
    ConstantInteger s;
    ConstantInteger b;
    ConstantInteger ch;
    ConstantInteger bo;
    ConstantUtf8 cu8;
    switch (getElementValueType()) {
      case 73:
        c = (ConstantInteger)getConstantPool().getConstant(this.idx);
        return Integer.toString(c.getBytes());
      case 74:
        j = (ConstantLong)getConstantPool().getConstant(this.idx);
        return Long.toString(j.getBytes());
      case 68:
        d = (ConstantDouble)getConstantPool().getConstant(this.idx);
        return Double.toString(d.getBytes());
      case 70:
        f = (ConstantFloat)getConstantPool().getConstant(this.idx);
        return Float.toString(f.getBytes());
      case 83:
        s = (ConstantInteger)getConstantPool().getConstant(this.idx);
        return Integer.toString(s.getBytes());
      case 66:
        b = (ConstantInteger)getConstantPool().getConstant(this.idx);
        return Integer.toString(b.getBytes());
      case 67:
        ch = (ConstantInteger)getConstantPool().getConstant(this.idx);
        return Integer.toString(ch.getBytes());
      case 90:
        bo = (ConstantInteger)getConstantPool().getConstant(this.idx);
        if (bo.getBytes() == 0)
          return "false"; 
        return "true";
      case 115:
        cu8 = (ConstantUtf8)getConstantPool().getConstant(this.idx);
        return cu8.getBytes();
    } 
    throw new IllegalStateException("SimpleElementValueGen class does not know how to stringify type " + getElementValueType());
  }
}
